This package includes the Rockset Python SDK that includes the following:

- Native Python API to connect to Rockset, manage data and execute queries. This API includes Rockset's query builder that allows for programmatic construction of advanced queries using native Python expressions.

- `rock` command line utility to interact, manage and operate Rockset from a shell command line.

- `rock` CLI does not include a SQL REPL command-line tool. Please install the `rockset_sqlcli` package to use that.

- SQL connector for Python, which conforms to the Python DB API 2.0 specification. Refer to https://www.python.org/dev/peps/pep-0249 for more details.

- SQLAlchemy dialect to bridge Rockset and SQLAlchemy applications. SQLAlchemy users can connect to Rockset using 'rockset://<api_key>:@<api_server>'

Rockset documentation is available at:
http://docs.rockset.com

